@@ -16,26 +16,26 @@ impl Printer {
     }
   }
 
-  pub fn summary(&self, data: HashMap<String, f64>) {
-    let mut data = utils::sort(&data, self.reverse);
+  pub fn summary(&self, plugins: &[Plugin]) {
+    let mut plugins = plugins.to_owned();
 
-    data.truncate(self.count.unwrap_or(10_usize));
+    plugins.truncate(self.count.unwrap_or(10_usize));
 
     let header = format!(
       "Top {} {} (n)vim plugins.",
-      data.len(),
+      plugins.len(),
       if self.reverse { "fastest" } else { "slowest" }
     );
 
     println!("{}", header);
     println!("{}", utils::repeat("=", header.len()));
 
-    for (i, (k, v)) in data.iter().enumerate() {
+    for (i, plugin) in plugins.iter().enumerate() {
       println!(
         "{} {} {:10}",
-        format!("{:<1$}", i + 1, data.len().to_string().len() + 2),
-        format!("{:1$}", k, utils::len_largest(&data)),
-        format!("{:.1$}", v, self.prec.unwrap_or(2_usize))
+        format!("{:<1$}", i + 1, plugins.len().to_string().len() + 2),
+        format!("{:1$}", plugin.name, &plugins.len_largest()),
+        format!("{:.1$}", plugin.average(), self.prec.unwrap_or(2_usize))
       );
     }
 
